==> dsalgo-0.2.0.tar.gz: dsalgo-0.2.0/README.md <==
# DsAlgo: Datastructures and Algorithms for Python
DsAlgo is a package for Datastructures and Algorithms written in Python.

[![Python package][ci-badge]][ci-url]
[![readthedocs build status][docs-badge]][docs-url]
[![pre-commit][pre-commit-badge]][pre-commit-url]
[![CodeQL][codeql-badge]][codeql-url]
[![License: MIT][mit-badge]][mit-url]
[![PyPI version][pypi-badge]][pypi-url]
[![Github pages][gh-pages-badge]][gh-pages-url]

[ci-badge]: https://github.com/kagemeka/dsalgo-python/actions/workflows/python-package.yml/badge.svg
[ci-url]: https://github.com/kagemeka/dsalgo-python/actions/workflows/python-package.yml
[docs-badge]: https://readthedocs.org/projects/dsalgo/badge/?version=latest
[docs-url]: https://dsalgo.readthedocs.io
[pre-commit-badge]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit-url]: https://github.com/pre-commit/pre-commit
[codeql-badge]: https://github.com/kagemeka/dsalgo-python/actions/workflows/codeql-analysis.yml/badge.svg
[codeql-url]: https://github.com/kagemeka/dsalgo-python/actions/workflows/codeql-analysis.yml
[mit-badge]: https://img.shields.io/badge/License-MIT-blue.svg
[mit-url]: https://opensource.org/licenses/MIT
[pypi-badge]: https://badge.fury.io/py/dsalgo.svg
[pypi-url]: https://badge.fury.io/py/dsalgo
[gh-pages-badge]: https://github.com/kagemeka/dsalgo-python/actions/workflows/pages/pages-build-deployment/badge.svg
[gh-pages-url]: https://kagemeka.github.io/dsalgo-python


## Installation

DsAlgo can be installed using pip:

```bash
$ python3 -m pip install -U dsalgo
```

If you want to run the latest version of the code, you can install from git:

```bash
$ python3 -m pip install -U git+git://github.com/kagemeka/dsalgo-python.git
```

## Contributing

see [CONTRIBUTING.md](./.github/docs/CONTRIBUTING.md)

==> dsalgo-0.2.5.tar.gz: dsalgo-0.2.5/README.md <==

# dsalgo

A package for Datastructures and Algorithms written in Python.

[![Python package][ci-badge]][ci-url]
[![PyPI version][pypi-badge]][pypi-url]
[![readthedocs build status][docs-badge]][docs-url]
[![License: MIT][mit-badge]][mit-url]
[![pre-commit][pre-commit-badge]][pre-commit-url]
[![Github pages][gh-pages-badge]][gh-pages-url]

[ci-badge]: https://github.com/kagemeka/dsalgo-python/actions/workflows/python-package.yml/badge.svg
[ci-url]: https://github.com/kagemeka/dsalgo-python/actions/workflows/python-package.yml
[docs-badge]: https://readthedocs.org/projects/dsalgo/badge/?version=latest
[docs-url]: https://dsalgo.readthedocs.io
[pre-commit-badge]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit-url]: https://github.com/pre-commit/pre-commit
[mit-badge]: https://img.shields.io/badge/License-MIT-blue.svg
[mit-url]: https://opensource.org/licenses/MIT
[pypi-badge]: https://badge.fury.io/py/dsalgo.svg
[pypi-url]: https://badge.fury.io/py/dsalgo
[gh-pages-badge]: https://github.com/kagemeka/dsalgo-python/actions/workflows/pages/pages-build-deployment/badge.svg
[gh-pages-url]: https://kagemeka.github.io/dsalgo-python

## Installation

```bash
python3 -m pip install -U dsalgo

python3 -m pip install -U git+git://github.com/kagemeka/dsalgo-python.git
# for latest unstable version
```

## Development

```sh
docker compose up -d  
```

(enter the container)

```sh
./setup.sh 
source ~/.bashrc
```

CI before commit

```sh
./ci.sh 
```

### documenting

```sh
poetry run pdoc dsalgo --show-source --math -o docs 
```

### publish

```sh
poetry config pypi-token.pypi <your token> # only once
poetry build 
poetry publish 
```
